==> apache-parquet-1.14.3.tar.gz: apache-parquet-1.14.3/dev/prepare-release.sh <==
#!/bin/bash
#
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
# 
#   http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.
#

set -e

[[ $# != 2 ]] && err="Incorrect number of arguments: $#"
[[ -z $err ]] && ! [[ $1 =~ ^[0-9]+\.[0-9]+\.[0-9]+$ ]] && err="Invalid release version: \"$1\""
[[ -z $err ]] && ! [[ $2 =~ ^[0-9]+$ ]] && err="Invalid rc number: \"$2\""

if [[ -n $err ]]; then
    cat <<EOF
$err
Usage: $0 <release-version> <rc-num>
Example: $0 1.11.0 7
EOF
  exit 1
fi

release_version="$1"
new_development_version="$release_version-SNAPSHOT"

tag="apache-parquet-$release_version-rc$2"

mvn release:clean
mvn release:prepare -DskipTests -Darguments=-DskipTests -Dtag="$tag" "-DreleaseVersion=$release_version" -DdevelopmentVersion="$new_development_version"

echo "Finish staging binary artifacts by running: mvn release:perform"

==> apache-parquet-1.15.1.tar.gz: apache-parquet-1.15.1/dev/prepare-release.sh <==
#!/bin/bash
#
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.
#

set -e

[[ $# != 2 ]] && err="Incorrect number of arguments: $#"
[[ -z $err ]] && ! [[ $1 =~ ^[0-9]+\.[0-9]+\.[0-9]+$ ]] && err="Invalid release version: \"$1\""
[[ -z $err ]] && ! [[ $2 =~ ^[0-9]+$ ]] && err="Invalid rc number: \"$2\""

if [[ -n $err ]]; then
    cat <<EOF
$err
Usage: $0 <release-version> <rc-num>
Example: $0 1.11.0 7
EOF
  exit 1
fi

release_version="$1"
new_development_version="$release_version-SNAPSHOT"

tag="apache-parquet-$release_version-rc$2"

./mvnw release:clean
./mvnw release:prepare -DskipTests -Darguments=-DskipTests -Dtag="$tag" "-DreleaseVersion=$release_version" -DdevelopmentVersion="$new_development_version"

echo "Finish staging binary artifacts by running: ./mvnw release:perform"
